@@ -10,9 +10,9 @@ Jim Turner
 
 =head1 SYNOPSIS
 
-use Date::Time2fmtstr;
+	use Date::Time2fmtstr;
 
-print time2str(time, 'mm-dd-yyyy hh:mi PM');
+	print time2str(time, 'mm-dd-yyyy hh:mi PM');
 
 =head1 DESCRIPTION
 
@@ -30,9 +30,11 @@ the corresponding date/time value.
 =item <$string> = B<time2str>(I<time>, I<format-string>);
 
 Returns a string corresponding to the specified I<format-string> with each special substring 
-replaced with the corresponding date/time data field.  For example:
+replaced with the corresponding date/time data field.
 
-$s = B<time2str>(1452324044, 'mm-dd-yyyy hh:mi PM (Day) (Month)');
+For example:
+
+	$s = B<time2str>(1452324044, 'mm-dd-yyyy hh:mi PM (Day) (Month)');
 
 would set $s to '01-09-2016 01:20 AM (Sat) (January)'.
 
@@ -43,17 +45,13 @@ number of combinations to produce the desired results.  They are listed below:
 
 =over 4
 
-B<month> - The Full name of the month in all lower case, ie. "january".
+B<a>, B<p> - display "a" if between Midnight and Noon, "p" otherwise (both specifiers are identical). 
 
-B<Month> - The Full name of the month capitalized, ie. "January". 
+B<A>, B<P> - display "A" if between Midnight and Noon, "P" otherwise (both specifiers are identical). 
 
-B<MONTH> - The Full name of the month all capitalized, ie. "JANUARY". 
+B<am>, B<pm> - display "am" if between Midnight and Noon, "pm" otherwise (both specifiers are identical). 
 
-B<dayofweek> - Day of the week in all lower case, ie. "sunday". 
-
-B<Dayofweek> - Day of the week capitalized, ie. "Sunday". 
-
-B<DAYOFWEEK> - Day of the week all capitalized, ie. "SUNDAY". 
+B<AM>, B<PM> - display "AM" if between Midnight and Noon, "PM" otherwise (both specifiers are identical). 
 
 B<day> - Three letter abbreviation of the day of the week in all lower case, ie. "sun". 
 
@@ -61,71 +59,109 @@ B<Day> - Three letter abbreviation of the day of the week capitalized, ie. "Sun"
 
 B<DAY> - Three letter abbreviation of the day of the week all capitalized, ie. "SUN". 
 
+B<dayofweek> - Day of the week in all lower case, ie. "sunday". 
+
+B<Dayofweek> - Day of the week capitalized, ie. "Sunday". 
+
+B<DAYOFWEEK> - Day of the week all capitalized, ie. "SUNDAY". 
+
 B<ddd> - Num. of days since beginning of year.
 
-B<dd> - Day of month (2 digits, left padded with a zero if needed), ie. "01".
-
-B<d1> - Day of month (1 or 2 digits, as needed), ie. "1". 
+B<dd> - Day of month (2 digits, left padded with a zero if needed), ie. "03" for March.
 
 B<d0>, B<d> - Numeric day of the week zero-based (Sunday=0, Monday=1, ... Saturday=6). 
 
-B<d1> - Numeric day of the week one-based (Sunday=1, Monday=2, ... Saturday=7). 
+B<d1> - Day of month (1 or 2 digits, as needed), ie. "3" for March. 
 
-B<yyyymmdd> - Numeric date in 8 digits, ie. "20150107" for January 7, 2015. 
+B<hh> - Hour in common format (left padded with a zero if needed for 2 digits), ie. 01-12.
 
-B<yyyy>, B<rrrr> - Year in 4 digits.
+B<hhmi> - Hours and minutes in 12-hour time (hours and minutes no colon, left padded 
+with a zero if needed for 4 digits).
 
-B<yy>, B<rr> - Year in last 2 digits.
+B<hhmiss> - Hours, minutes and seconds in 12-hour time (no colon, left padded 
+with a zero if needed for 6 digits).
 
-B<hh24> - Military time (hours and minutes: 24 hours, no colon).
+B<hh24>, B<HHmi> - Military time (hours and minutes: 24 hours, no colon), left padded 
+with a zero if needed for 4 digits).
 
-B<hh> - Hour in common format, ie. 01-12.
+B<h1> - Hour in common format, 1 or 2 digits, as needed, ie. 1-12. (see B<AM> and B<PM> 
+specifiers).
 
-B<h1> - Hour in common format, 1 or 2 digits, as needed, ie. 1-12. 
-
-B<mi> - Minute, ie. 00-59. 
-
-B<mm> - Number of month (2 digits, left padded with a zero if needed), ie. "01" for January. 
-
-B<mon> - Three letter abbreviation of the month, in lower case, ie. "jan" for January. 
+B<h1mi> - Hours and minutes in 12-hour time (hours and minutes no colon).  Returns 3 or 
+4 digits as needed.
 
 B<HH> - Hour in 24-hour format, 2 digits, left padded with a zero if needed, ie. 00-23. 
 
 B<H1> - Hour in 24-hour format, 1 or 2 digits, as needed, ie. 0-23. 
 
+B<HHmiss> - Hours, minutes and seconds in 24-hour (military) time (no colon, left padded 
+with a zeros if needed for 6 digits).
+
+B<mi> - Minute, (2 digits, left padded with a zero if needed), ie. 00-59.
+
+B<mm> - Number of month (2 digits, left padded with a zero if needed), ie. "01" for January. 
+
+B<mmdd> - Numeric date in 4 digits, ie. "0107" for January, 7, (current year). 
+
+B<mmddyy> - Numeric date in 6 digits, ie. "010715" for January 7, 2015. 
+
+B<mmddyyyy> - Numeric date in 8 digits, ie. "01072015" for January 7, 2015. 
+
+B<mmyy> - Numeric date in 4 digits, ie. "0115" for January, 2015. 
+
+B<mmyyyy> - Numeric date in 6 digits, ie. "012015" for January, 2015. 
+
+B<mmmm> - Minutes since start of day (0000-3599).
+
+B<mmm0> - Minutes since start of day (0-3599).
+
+B<mon> - Three letter abbreviation of the month, in lower case, ie. "jan" for January. 
+
 B<Mon> - Three letter abbreviation of the month, capitalized, ie. "Jan" for January. 
 
 B<MON> - Three letter abbreviation of the month all capitalized, ie. "JAN" for January. 
 
+B<month> - The Full name of the month in all lower case, ie. "january".
+
+B<Month> - The Full name of the month capitalized, ie. "January". 
+
+B<MONTH> - The Full name of the month all capitalized, ie. "JANUARY". 
+
 B<m1> - Number of month (1 or 2 digits, as needed), ie. "1" for January. 
 
-B<sssss> - Seconds since start of day (00000-86399). 
-
-B<ssss0> - Seconds since start of day (0-86399). 
-
-B<mmmm> - Minutes since start of day (0000-3599. 
-
-B<mmm0> - Minutes since start of day (0-3599. 
-
-B<ss> - Seconds since start of last minute (2 digits), ie. 00-59. 
-
-B<am>, B<pm> - display "am" if between Midnight and Noon, "pm" otherwise (both specifiers are identical). 
-
-B<AM>, B<PM> - display "AM" if between Midnight and Noon, "PM" otherwise (both specifiers are identical). 
-
-B<a>, B<p> - display "a" if between Midnight and Noon, "p" otherwise (both specifiers are identical). 
-
-B<A>, B<P> - display "A" if between Midnight and Noon, "P" otherwise (both specifiers are identical). 
+B<q> - Number of the quarter of the year - (1-4).
 
 B<rm> - Roman numeral for the month (i-xii) in lower case. 
 
 B<RM> - Roman numeral for the month (I-XII) in upper case. 
 
-B<w> - Number of week of the month (1-5). 
+B<ss> - Seconds since start of last minute (2 digits), ie. 00-59. 
 
-B<ww> - Number of week of the year (1-51). 
+B<sssss> - Seconds since start of day (00000-86399). 
 
-B<q> - Number of the quarter of the year - (1-4).
+B<ssss0> - Seconds since start of day (0-86399). 
+
+B<w> - Number of week (one-based) of the month (1-5). 
+
+B<ww> - Number of week (one-based) of the year (1-52). 
+
+B<yy>, B<rr> - Year in last 2 digits.
+
+B<yymm> - Numeric date in 4 digits, ie. "1501" for January, 2015. 
+
+B<yymmdd> - Numeric date in 6 digits, ie. "150107" for January 7, 2015. 
+
+B<yyyymmdd> - Numeric date in 8 digits, ie. "20150107" for January 7, 2015. 
+
+B<yyyymmddhhmi> - Numeric date/time in 12 digits, ie. "201501071345" for January 7, 2015 1:45pm. 
+
+B<yyyymmddhhmiss> - Numeric date/time in 14 digits, ie. "20150107134512" for January 7, 2015 1:45:12pm. 
+
+B<yyyymm> - Numeric date in 6 digits, ie. "201501" for January, 2015. 
+
+B<yyyy>, B<rrrr> - Year in 4 digits.
+
+B<yyyymmdd> - Numeric date in 8 digits, ie. "20150107" for January 7, 2015. 
 
 =back
 
@@ -139,8 +175,6 @@ Perl 5
 
 L<Date::Fmtstr2time>, L<String::PictureFormat>
 
-wget
-
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-Date-Time2fmtstr at rt.cpan.org>, or through
@@ -230,7 +264,7 @@ package Date::Time2fmtstr;
 use strict;
 #use warnings;
 use vars qw(@ISA @EXPORT $VERSION);
-$VERSION = '1.03';
+$VERSION = '1.10';
 
 require Exporter;
 
@@ -242,6 +276,8 @@ my @inputs = ();
 sub time2str
 {
 	my $s = $_[0] || time;
+	return "e:Invalid Time ($s) not numeric!"  if ($s =~ /\D/);
+
 	my $f = $_[1] || 'yyyymmdd';
 
 	my @fmts = split(/\b/, $f);
@@ -260,9 +296,11 @@ OUTER1:	for (my $i=0;$i<=$#fmts;$i++)
 		}
 MIDDLE1:		while ($fmts[$i] =~ /\w/o)
 		{
-			foreach my $f (qw(month Month MONTH dayofweek Dayofweek DAYOFWEEK day Day DAY
-					ddd dd d1 d0 yyyymmdd yyyy yy hh24 hh HH H1 h1 mi mmm0 mmmm mm mon 
-					Mon MON m1 ssss0 sssss ss am pm AM PM a p A P rm RM rr d ww w q))
+			foreach my $f (qw(month Month MONTH dayofweek Dayofweek DAYOFWEEK day Day DAY	ddd
+					dd d1 d0 mmddyyyy yyyymmddhhmiss yyyymmddhhmi yyyymmdd yyyymm yymmdd mmyyyy 
+					mmddyy yyyy yymm mmyy yy mmdd hh24 HHmiss hhmiss HHmi h1mi hhmi hh HH H1 h1 mi 
+					mmm0 mmmm mm mon Mon MON m1 ssss0 sssss ss am pm AM PM a p A P rm RM rr d 
+					ww w q))
 			{
 				if ($fmts[$i] =~ s/^$f//)
 				{
@@ -290,7 +328,7 @@ sub _toc_month
 	my @mthlist = (qw(january february march april may june july august september 
 			october november december));
 
-	return "Invalid Month ($inputs[4])! "  unless ($inputs[4] >= 0 && $inputs[4] < 12);
+	return "e:Invalid Month ($inputs[4])! "  unless ($inputs[4] >= 0 && $inputs[4] < 12);
 	return $mthlist[$inputs[4]];
 }
 
@@ -310,7 +348,7 @@ sub _toc_mon
 {
 	my @mthlist = (qw(jan feb mar apr may jun jul aug sep oct nov dec));
 
-	return "Invalid Month ($inputs[4])! "  unless ($inputs[4] >= 0 && $inputs[4] < 12);
+	return "e:Invalid Month ($inputs[4])! "  unless ($inputs[4] >= 0 && $inputs[4] < 12);
 	return $mthlist[$inputs[4]];
 }
 
@@ -330,7 +368,7 @@ sub _toc_rm   #ROMAN NUMBER MONTH - LOWER CASE
 {
 	my @mthlist = (qw(i ii iii iv v vi vii viii ix x xi xii));
 
-	return "Invalid Month ($inputs[4])! "  unless ($inputs[4] >= 0 && $inputs[4] < 12);
+	return "e:Invalid Month ($inputs[4])! "  unless ($inputs[4] >= 0 && $inputs[4] < 12);
 	return $mthlist[$inputs[4]];
 }
 
@@ -343,7 +381,7 @@ sub _toc_RM   #ROMAN NUMBER MONTH - UPPER CASE
 sub _toc_mm   #MONTH (01-12)
 {
 	my $mymth = $inputs[4] + 1;
-	return "Invalid Month ($mymth)! "  unless ($mymth >= 1 && $mymth <= 12);
+	return "e:Invalid Month ($mymth)! "  unless ($mymth >= 1 && $mymth <= 12);
 	return '0'.$mymth  if ($mymth < 10);
 	return $mymth;
 }
@@ -351,27 +389,77 @@ sub _toc_mm   #MONTH (01-12)
 sub _toc_m1   #MONTH (1-12)
 {
 	my $mymth = $inputs[4] + 1;
-	return "Invalid Month ($mymth)! "  unless ($mymth >= 1 && $mymth <= 12);
+	return "e:Invalid Month ($mymth)! "  unless ($mymth >= 1 && $mymth <= 12);
 	return $mymth;
 }
 
+sub _toc_yy
+{
+	my $myyr = $inputs[5];
+	return "e:Invalid Year ($myyr)! "  unless ($myyr =~ /^[0-9]+$/o);
+	$myyr -= 100  while ($myyr >= 100);
+	return  '0'.$myyr  if ($myyr < 10);
+	return $myyr;
+}
+
+sub _toc_mmddyyyy
+{
+	return &_toc_mm() . &_toc_dd() . &_toc_yyyy();
+}
+
 sub _toc_yyyymmdd
 {
 	return &_toc_yyyy() . &_toc_mm() . &_toc_dd();
 }
 
+sub _toc_yyyymmddhhmiss
+{
+	return &_toc_yyyy() . &_toc_mm() . &_toc_dd() . &_toc_HH() . &_toc_mi() . &_toc_ss();
+}
+
+sub _toc_yyyymmddhhmi
+{
+	return &_toc_yyyy() . &_toc_mm() . &_toc_dd() . &_toc_HH() . &_toc_mi();
+}
+
+sub _toc_yyyymm
+{
+	return &_toc_yyyy() . &_toc_mm();
+}
+
+sub _toc_yymmdd
+{
+	return &_toc_yy() . &_toc_mm() . &_toc_dd();
+}
+
+sub _toc_mmyyyy
+{
+	return &_toc_mm() . &_toc_yyyy();
+}
+
+sub _toc_mmddyy
+{
+	return &_toc_mm() . &_toc_dd() . &_toc_yy();
+}
+
+sub _toc_yymm
+{
+	return &_toc_yy() . &_toc_mm();
+}
+
 sub _toc_yyyy   #4-DIGIT YEAR
 {
 	return $inputs[5] + 1900;
 }
 
-sub _toc_yy
+sub _toc_mmyy
 {
-	my $myyr = $inputs[5];
-	return "Invalid Year ($myyr)! "  unless ($myyr =~ /^[0-9]+$/o);
-	$myyr -= 100  while ($myyr >= 100);
-	return  '0'.$myyr  if ($myyr < 10);
-	return $myyr;
+	return &_toc_mm() . &_toc_yy();
+}
+
+sub _toc_mmdd
+{
+	return &_toc_mm() . &_toc_dd();
 }
 
 sub _toc_rr
@@ -433,6 +521,26 @@ sub _toc_h1     #HOUR (1-12)
 	return $hr;
 }
 
+sub HHmi {
+	return &_toc_HH24();
+}
+
+sub hhmi {
+	return &_toc_hh() . &_toc_mi();
+}
+
+sub h1mi {
+	return &_toc_h1() . &_toc_mi();
+}
+
+sub HHmiss {
+	return &_toc_HH() . &_toc_mi() . &_toc_ss();
+}
+
+sub hhmiss {
+	return &_toc_hh() . &_toc_mi() . &_toc_ss();
+}
+
 sub _toc_a
 {
 	return ($inputs[2] < 12) ? 'a' : 'p';
@@ -491,7 +599,6 @@ sub _toc_sssss    #SECONDS OF THE DAY (0-86399)
 
 sub _toc_mmm0    #MINUTES OF THE DAY (0-3599)
 {
-print "--INPUTS(2)=$inputs[2]= 1=$inputs[1]= 0=$inputs[0]=\n";
 	return ($inputs[2]*60)+$inputs[1];
 }
 
@@ -520,7 +627,7 @@ sub _toc_day
 {
 	my @daylist = (qw(sun mon tue wed thu fri sat));
 
-	return "Invalid Day ($inputs[6])! "  unless ($inputs[6] >= 0 && $inputs[6] < 7);
+	return "e:Invalid Day ($inputs[6])! "  unless ($inputs[6] >= 0 && $inputs[6] < 7);
 	return $daylist[$inputs[6]];
 }
 
@@ -540,7 +647,7 @@ sub _toc_dayofweek
 {
 	my @daylist = (qw(sunday monday tuesday wednesday thursday friday saturday));
 
-	return "Invalid Day ($inputs[6])! "  unless ($inputs[6] >= 0 && $inputs[6] < 7);
+	return "e:Invalid Day ($inputs[6])! "  unless ($inputs[6] >= 0 && $inputs[6] < 7);
 	return $daylist[$inputs[6]];
 }
 
